@@ -10,11 +10,9 @@ use self::{
 use crate::util::EndsWithAlphaNum;
 use memchr::memmem::Finder;
 use once_cell::sync::Lazy;
-use std::{borrow::Cow, fmt::Write, io, sync::Arc};
+use std::{borrow::Cow, fmt::Write, io};
 use swc_atoms::JsWord;
-use swc_common::{
-    comments::Comments, sync::Lrc, BytePos, SourceMap, Span, Spanned, SyntaxContext, DUMMY_SP,
-};
+use swc_common::{comments::Comments, sync::Lrc, BytePos, SourceMap, Span, Spanned, DUMMY_SP};
 use swc_ecma_ast::*;
 use swc_ecma_codegen_macros::emitter;
 use swc_ecma_parser::JscTarget;
@@ -612,7 +610,9 @@ where
             Expr::Invalid(ref n) => emit!(n),
         }
 
-        self.emit_trailing_comments_of_pos(node.span().hi, true, true)?;
+        if self.comments.is_some() {
+            self.emit_trailing_comments_of_pos(node.span().hi, true, true)?;
+        }
     }
 
     #[emitter]
@@ -792,7 +792,9 @@ where
 
     #[emitter]
     fn emit_meta_prop_expr(&mut self, node: &MetaPropExpr) -> Result {
-        self.emit_leading_comments_of_span(node.span(), false)?;
+        if self.comments.is_some() {
+            self.emit_leading_comments_of_span(node.span(), false)?;
+        }
 
         emit!(node.meta);
         punct!(".");
@@ -1508,7 +1510,9 @@ where
 
     #[emitter]
     fn emit_expr_or_spread(&mut self, node: &ExprOrSpread) -> Result {
-        self.emit_leading_comments_of_span(node.span(), false)?;
+        if self.comments.is_some() {
+            self.emit_leading_comments_of_span(node.span(), false)?;
+        }
 
         if node.spread.is_some() {
             punct!("...");
@@ -1857,9 +1861,11 @@ where
                     // -> this comment isn't considered to be trailing comment of parameter "a" due
                     // to newline ,
                     if format.contains(ListFormat::DelimitersMask)
-                        && previous_sibling.span().hi() != parent_node.hi()
+                        && previous_sibling.hi != parent_node.hi()
                     {
-                        self.emit_leading_comments(previous_sibling.span().hi(), true)?;
+                        if self.comments.is_some() {
+                            self.emit_leading_comments(previous_sibling.span().hi(), true)?;
+                        }
                     }
 
                     self.write_delim(format)?;
@@ -1894,8 +1900,10 @@ where
 
                 // Emit this child.
                 if should_emit_intervening_comments {
-                    let comment_range = child.comment_range();
-                    self.emit_trailing_comments_of_pos(comment_range.hi(), false, true)?;
+                    if self.comments.is_some() {
+                        let comment_range = child.comment_range();
+                        self.emit_trailing_comments_of_pos(comment_range.hi(), false, true)?;
+                    }
                 } else {
                     should_emit_intervening_comments = may_emit_intervening_comments;
                 }
@@ -1954,7 +1962,9 @@ where
                         && previous_sibling.span().hi() != parent_node.hi()
                         && emit_trailing_comments
                     {
-                        self.emit_leading_comments(previous_sibling.span().hi(), true)?;
+                        if self.comments.is_some() {
+                            self.emit_leading_comments(previous_sibling.span().hi(), true)?;
+                        }
                     }
                 }
             }
@@ -2023,7 +2033,9 @@ where
             Pat::Invalid(n) => emit!(n),
         }
 
-        self.emit_trailing_comments_of_pos(node.span().hi, true, true)?;
+        if self.comments.is_some() {
+            self.emit_trailing_comments_of_pos(node.span().hi, true, true)?;
+        }
     }
 
     #[emitter]
@@ -2050,7 +2062,9 @@ where
 
     #[emitter]
     fn emit_spread_element(&mut self, node: &SpreadElement) -> Result {
-        self.emit_leading_comments_of_span(node.span(), false)?;
+        if self.comments.is_some() {
+            self.emit_leading_comments_of_span(node.span(), false)?;
+        }
 
         punct!("...");
         emit!(node.expr)
@@ -2216,7 +2230,9 @@ where
             Stmt::ForOf(ref e) => emit!(e),
             Stmt::Decl(ref e) => emit!(e),
         }
-        self.emit_trailing_comments_of_pos(node.span().hi(), true, true)?;
+        if self.comments.is_some() {
+            self.emit_trailing_comments_of_pos(node.span().hi(), true, true)?;
+        }
 
         if !self.cfg.minify {
             self.wr.write_line()?;
@@ -2777,25 +2793,6 @@ where
     }
 }
 
-#[allow(dead_code)]
-fn get_text_of_node<T: Spanned>(
-    cm: &Arc<SourceMap>,
-    node: &T,
-    _include_travia: bool,
-) -> Option<String> {
-    let span = node.span();
-    if span.is_dummy() || span.ctxt() != SyntaxContext::empty() {
-        // This node is transformed so we shoukld not use original source code.
-        return None;
-    }
-
-    let s = cm.span_to_snippet(span).unwrap();
-    if s == "" {
-        return None;
-    }
-    Some(s)
-}
-
 /// In some cases, we need to emit a space between the operator and the operand.
 /// One obvious case is when the operator is an identifier, like delete or
 /// typeof. We also need to do this for plus and minus expressions in certain
@@ -2932,10 +2929,6 @@ fn unescape_tpl_lit(s: &str, is_synthesized: bool) -> String {
                     result.push_str("\n");
                 }
 
-                '`' if is_synthesized => {
-                    result.push_str("\\`");
-                }
-
                 // TODO: Handle all escapes
                 _ => {
                     result.push(c);
